Skip to main content

Quarto Batch Converter

Description

Quarto Batch Converter is a utility that converts ipynb files to qmd files using the Quarto command line. This tool is designed to simplify the process of converting multiple ipynb files at once, making it ideal for large projects or batch conversions.

This cli is equivalent to perform the following statement on multiple times:

quarto convert file.ipynb

Features

  • Converts files to files using quarto convert (ipynb to qmd, qmd to ipynb)
  • Filters file based on extension (default: ipynb)
  • Filters file based on a match pattern that could be replaced for the output file (e.g. _test.ipynb -> test.qmd)
  • Preserves the original directory structure of the input files
  • Allows specifying a prefix for the converted files
  • Supports glob style paths as well as recursion in the subdirectory

Installation

To install Quarto Batch Converter, run the following command:

pipx install quarto_batch_convert

This will install the package and make the quarto_batch_convert and its alias qbc command line available.

Usage

To use Quarto Batch Converter, navigate to the directory containing the ipynb files you want to convert and run the following command:

quarto_batch_convert <input_paths> [options]

Replace <input_paths> with one or more directory paths, file paths, or glob patterns to search for ipynb files.

Options

  • -e, --extension: File extension to filter files when input is a directory (default: .ipynb)
  • -m, --match-replace-pattern: Match pattern and optional replace pattern, separated by a forward slash. If no slash is present, only matching is performed.
  • -p, --prefix: Prefix to add to the new file name
  • -k, --keep-extension: Keep the original extension as part of the filename
  • -o, --output-path: Output path where to generate the .qmd files (default: current directory)
  • -r, --recursive: Search files recursively when input is a directory

Examples

  • Convert all ipynb files in the current directory (no subdirectory):
quarto_batch_convert .
  • Convert all ipynb files in the notebooks directory and its subdirectories:
quarto_batch_convert notebooks -r
  • Convert all ipynb files in the notebooks directory and add a prefix converted_ to the output files:
quarto_batch_convert notebooks -p converted_
  • Convert all ipynb files in the notebooks directory and replace the string old_ with new_ in the file names:
quarto_batch_convert notebooks -m old_/new_

Contributing

Contributions to Quarto Batch Converter are welcome. If you have any issues or feature requests, please submit a pull request or open an issue on the GitHub repository.

License

Quarto Batch Converter is licensed under the MIT License.

Metadata

Release files for quarto-batch-convert 2025.9.2

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for quarto-batch-convert 2025.9.2
File Size Uploaded
quarto_batch_convert-2025.9.2.tar.gz 6.0 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for quarto-batch-convert 2025.9.2
File Interpreter ABI Platform
quarto_batch_convert-2025.9.2-py3-none-any.whl Python 3 none any Details

Total release size: 13.9 kB

Release files / quarto_batch_convert-2025.9.2.tar.gz

Download URL quarto_batch_convert-2025.9.2.tar.gz
Size 6.0 kB
Tags Source
SHA-256 checksum
How to use checksums
5d619d80ebe79ab01519ae571f07c1ccff142a8d6b9fa7be921c18f0d4e0892f
BLAKE2b-256 checksum
How to use checksums
1139e044873854662c6af0fce7a59b5046e1f066906d9bbe818a632bb4311da4
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via twine/6.1.0 CPython/3.13.7

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

PyPI Publish Attestation

PyPI verified that this artifact, at this checksum, originated from the publisher listed below.

Signed by GitHub Actions, verified by PyPI on Dec 1, 2025.

Transparency log

Release files / quarto_batch_convert-2025.9.2-py3-none-any.whl

Download URL quarto_batch_convert-2025.9.2-py3-none-any.whl
Size 7.9 kB
Tags Python 3
SHA-256 checksum
How to use checksums
e64ba53f03d055c1af8fd4d2f3d393ce20233fc2ae18652c4ece26f80f0ca1b1
BLAKE2b-256 checksum
How to use checksums
3d60c3b17885d7835b55f4d03606d857ee8d08e14884c99d10c3ac73715f4a0d
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via twine/6.1.0 CPython/3.13.7

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

PyPI Publish Attestation

PyPI verified that this artifact, at this checksum, originated from the publisher listed below.

Signed by GitHub Actions, verified by PyPI on Dec 1, 2025.

Transparency log
Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page